package com.ruoyi.zongzhi.mapper;

import java.util.List;
import com.ruoyi.zongzhi.domain.TcSafetyDetection;

/**
 * 安全检测Mapper接口
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
public interface TcSafetyDetectionMapper 
{
    /**
     * 查询安全检测
     * 
     * @param id 安全检测主键
     * @return 安全检测
     */
    public TcSafetyDetection selectTcSafetyDetectionById(Long id);

    /**
     * 查询安全检测列表
     * 
     * @param tcSafetyDetection 安全检测
     * @return 安全检测集合
     */
    public List<TcSafetyDetection> selectTcSafetyDetectionList(TcSafetyDetection tcSafetyDetection);

    /**
     * 新增安全检测
     * 
     * @param tcSafetyDetection 安全检测
     * @return 结果
     */
    public int insertTcSafetyDetection(TcSafetyDetection tcSafetyDetection);

    /**
     * 修改安全检测
     * 
     * @param tcSafetyDetection 安全检测
     * @return 结果
     */
    public int updateTcSafetyDetection(TcSafetyDetection tcSafetyDetection);

    /**
     * 删除安全检测
     * 
     * @param id 安全检测主键
     * @return 结果
     */
    public int deleteTcSafetyDetectionById(Long id);

    /**
     * 批量删除安全检测
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteTcSafetyDetectionByIds(Long[] ids);
}
